Learn R Programming

toRvik (version 1.1.1)

bart_archive: Get T-Rank Archive Ratings

Description

Returns T-Rank ratings and efficiency metrics from the morning of the specified day. Data goes back to 2014-15.

Usage

bart_archive(date = NULL, team = NULL, year = NULL)

Value

Returns a tibble with 16 columns:

rk

double.

team

character.

conf

character.

rec

character.

barthag

double. The estimation of a team's win probability against the average Division 1 team on a neutral court.

adj_o

double.

adj_o_rk

double.

adj_d

double.

adj_d_rk

double.

adj_tempo

double.

adj_tempo_rk

double.

proj_rec

character.

proj_conf_rec

character.

wab

double. The number of wins above or below the expected total from a bubble team against the same schedule.

wab_rk

double.

date

double.

Arguments

date

Date to filter for (YYYYMMDD).

team

Team to filter for.

year

Year to filter for.

Examples

Run this code
try(bart_archive(date='20220113'))

Run the code above in your browser using DataLab