Learn R Programming

toRvik (version 1.1.1)

bart_player_game: Get Player Game Stats

Description

Returns detailed game-by-game player statistics on a variety of splits.

Usage

bart_player_game(
  year = current_season(),
  stat = NULL,
  game_id = NULL,
  player_id = NULL,
  exp = NULL,
  team = NULL,
  conf = NULL,
  load_all = FALSE,
  ...
)

Value

Returns a tibble with the number of columns dependent on the value supplied to the `stat` argument.

Arguments

year

Year to filter.

stat

Indicates statistical split (see details).

game_id

Game to filter.

player_id

Player to filter.

exp

Player experience to filter.

team

Team to filter.

conf

Conference to filter.

load_all

Load all available data (boolean); defaults to FALSE.

...

Acceptable parameters for API. Used for function development

Details

Data is split on three statistical types, explained below:

box

Returns basic box score stats; sorts by ppg.

shooting

Returns play-by-play shooting splits; sorts by ppg.

advanced

Returns advanced metrics and possession-adjusted box score statistics; sorts by recruiting rank.

all

Used when `load_all` is TRUE to return all data

Examples

Run this code
try(bart_player_game(year=2022, stat='box'))

Run the code above in your browser using DataLab