powered by
Returns T-Rank ratings and efficiency metrics from the morning of the specified day. Data goes back to 2014-15.
bart_archive(date = NULL, team = NULL, year = NULL)
Returns a tibble with 16 columns:
rk
double.
team
character.
conf
rec
barthag
double. The estimation of a team's win probability against the average Division 1 team on a neutral court.
adj_o
adj_o_rk
adj_d
adj_d_rk
adj_tempo
adj_tempo_rk
proj_rec
proj_conf_rec
wab
double. The number of wins above or below the expected total from a bubble team against the same schedule.
wab_rk
date
Date to filter for (YYYYMMDD).
Team to filter for.
Year to filter for.
try(bart_archive(date='20220113'))
Run the code above in your browser using DataLab