bart_coach: Get Coaching History and Notable Recruits
Description
Returns coaching history with four factor and tournament finish (tibble one)
along with notable recruits (tibble two).
Usage
bart_coach(coach)
Value
Returns a list of tibbles: 'Coach History' and 'Recruiting History'
Arguments
coach
Coach to return.
Details
For a brief explanation of each factor and its computation, please visit
KenPom's blog. `rec_rank` is a
scale of recruiting ranking, where 100 is a consensus #1 recruit and 0 is
unrecruited.