Returns conference-wide four factor data on a variety of splits, including date range, quadrant level, opponent ranking, game location, and game type.
bart_conf_factors(
year = current_season(),
conf = NULL,
opp_conf = NULL,
type = NULL,
location = NULL,
start = NULL,
end = NULL
)Returns a tibble with 21 columns:
confcharacter.
ratingdouble. Expected scoring margin against an average team on a neutral court.
rankdouble.
adj_odouble.
adj_o_rankdouble.
adj_ddouble.
adj_d_rankdouble.
tempodouble.
off_pppdouble. Raw points scored per possession.
off_efgdouble. Team effective FG%.
off_todouble. Offensive turnover rate.
off_ordouble. Offensive rebound rate.
off_ftrdouble. Offensive free throw rate.
def_pppdouble. Raw points allowed per possession.
def_efgdouble. Effective FG% allowed.
def_todouble. Turnover rate forced.
def_ordouble. Defensive rebound rate.
def_ftrdouble. Free throw rate allowed.
winsinteger.
lossesinteger.
gamesinteger.
Filters to year (YYYY)
Filters to conference
Filters to opponent conference
Filters to game type ('nc', 'conf', or 'post')
Filters to game location ('H', 'A', or 'N')
Filters by starting date (YYYY-MM-DD)
Filters by ending date (YYYY-MM-DD)
For a brief explanation of each factor and its computation, please visit KenPom's blog. Data can be split on five variables:
Splits on game location; 'all', 'home', 'away', 'neutral', and 'road' (away + neutral).
Splits on game type; 'all', 'nc' (non-conference), 'conf' (conference), 'reg' (regular season), 'post' (post-season tournaments), 'ncaa' (NCAA tournament).
Splits by quadrant level; 1-4 with 0 indicating 1-A games.
Splits by opponent T-Rank position, adjusted for game location.
Splits by date range (YYYYMMDD).
try(bart_conf_factors(type='nc'))
Run the code above in your browser using DataLab