Returns four factor data and team records on a variety of splits, including date range, quadrant level, opponent ranking, game location, and game type.
bart_factors(
year = current_season(),
result = NULL,
type = NULL,
start = NULL,
end = NULL,
location = NULL,
last = NULL
)Returns a tibble with 22 columns:
teamcharacter.
confcharacter.
ratingdouble. Expected scoring margin against an average team on a neutral court.
rankdouble.
adj_odouble.
adj_o_rankdouble.
adj_ddouble.
adj_d_rankdouble.
tempodouble.
off_pppdouble. Raw points scored per possession.
off_efgdouble. Team effective FG%.
off_todouble. Offensive turnover rate.
off_ordouble. Offensive rebound rate.
off_ftrdouble. Offensive free throw rate.
def_pppdouble. Raw points allowed per possession.
def_efgdouble. Effective FG% allowed.
def_todouble. Turnover rate forced.
def_ordouble. Defensive rebound rate.
def_ftrdouble. Free throw rate allowed.
winsinteger.
lossesinteger.
gamesinteger.
Defaults to current season (YYYY).
Filters by result ('W' or 'L')
Filter by game type ('nc', 'conf', or 'post')
Filters by starting date (YYYY-MM-DD)
Filters by ending date (YYYY-MM-DD)
Filters by game location ('H', 'A', or 'N')
Filters by last x games played
For a brief explanation of each factor and its computation, please visit KenPom's blog.
try(bart_factors(year=2022, start='2022-01-13', type='conf'))
Run the code above in your browser using DataLab