Learn R Programming

toRvik (version 1.1.1)

bart_game_box: Get Team Game Stats

Description

Returns box score data by team for all games.

Usage

bart_game_box(
  year = current_season(),
  date = NULL,
  team = NULL,
  conf = NULL,
  game_id = NULL
)

Value

Returns a tibble of box score statistics

Arguments

year

Filters to year (YYYY)

date

Filters to date (YYYY-MM-DD)

team

Filters to team

conf

Filters to conference

game_id

Filters to game

Details

The home team is coded as `team2`. Neutral site games may contain errors as to whom is the home team.

Examples

Run this code
try(bart_game_box(year=2022))

Run the code above in your browser using DataLab