Learn R Programming

toRvik (version 1.1.1)

bart_game_factors: Get Game Four Factors

Description

Returns game-by-game four factor statistics.

Usage

bart_game_factors(
  year = current_season(),
  team = NULL,
  conf = NULL,
  opp_conf = NULL,
  type = NULL,
  location = NULL,
  result = NULL
)

Value

Returns a tibble of four factor statistics

Arguments

year

Defaults to current season (YYYY).

team

Filters to team.

conf

Filters to conference.

opp_conf

Filters to opponent's conference.

type

Filters for game type ('nc', 'conf', 'conf_t', 'post')

location

Filters for game location ('H', 'A', 'N')

result

Filters for game result.

Details

For a brief explanation of each factor and its computation, please visit KenPom's blog. `avg_marg` and `opp_avg_marg` is the the average lead or deficit during a game.

Examples

Run this code
try(bart_game_factors(year=2022))

Run the code above in your browser using DataLab