powered by
Returns detailed game-by-game player statistics on a variety of splits.
bart_player_game( year = current_season(), stat = NULL, game_id = NULL, player_id = NULL, exp = NULL, team = NULL, conf = NULL, load_all = FALSE, ... )
Returns a tibble with the number of columns dependent on the value supplied to the `stat` argument.
Year to filter.
Indicates statistical split (see details).
Game to filter.
Player to filter.
Player experience to filter.
Team to filter.
Conference to filter.
Load all available data (boolean); defaults to FALSE.
Acceptable parameters for API. Used for function development
Data is split on three statistical types, explained below:
Returns basic box score stats; sorts by ppg.
Returns play-by-play shooting splits; sorts by ppg.
Returns advanced metrics and possession-adjusted box score statistics; sorts by recruiting rank.
Used when `load_all` is TRUE to return all data
try(bart_player_game(year=2022, stat='box'))
Run the code above in your browser using DataLab