bart_player_splits: Get Player Season Splits
Description
Returns season-long player statistics on a variety of splits.
Usage
bart_player_splits(
year = current_season(),
split = NULL,
team = NULL,
conf = NULL,
exp = NULL,
player_id = NULL,
type = NULL
)
Value
Returns a tibble with the number of columns dependent on the value
supplied to the `stat` argument.
Arguments
- year
Year to filter.
- split
Split to filter (see details).
- team
Team to filter.
- conf
Conference to filter.
- exp
Experience to filter.
- player_id
Unique player ID to filter.
- type
Data type to return (see details).
Details
Data is split on three statistical types, explained below:
- box
Returns basic box score stats; sorts by ppg.
- shooting
Returns play-by-play shooting splits; sorts by ppg.
- advanced
Returns advanced metrics and possession-adjusted box score
statistics; sorts by recruiting rank.
Examples
Run this codetry(bart_player_splits(year=2022, conf='ACC'))
Run the code above in your browser using DataLab