Returns pregame win probabilities, expected scores, and thrill quotients for all games.
bart_pregame(year = current_season(), team = NULL, type = NULL, game_id = NULL)Returns a tibble with 13 columns:
datedouble.
confcharacter.
linecharacter.
ttqdouble. Torvik Thrill Quotient -- measures how good the teams are, how close the game is projected to be, and how fast the tempo is projected to be.
typecharacter. See details.
team1character.
team1_wpdouble. Estimated win percentage.
team1_ptsdouble. Estimated total points.
team2character.
team2_wpdouble. Estimated win percentage.
team2_ptsdouble. Estimated total points.
game_idcharacter.
yeardouble.
Defaults to current season (YYYY).
Team to filter for.
Game type to filter for ('nc', 'conf', 'conf_t', 'post', 'nond1')
Game ID to filter for.
Under the `type` column, games are classified by one of five indicators, explained below:
Non-conference games between two D-1 teams.
In-conference games.
Conference tournament games.
Post-conference tournament games.
Games involving one non-D1 team.