powered by
Returns current T-Rank ratings and two forms of strength of schedule.
bart_ratings(year = current_season())
Returns a tibble with 19 columns:
team
character.
conf
barthag
double. The estimation of a team's win probability against the average Division 1 team on a neutral court.
barthag_rk
integer.
adj_o
double.
adj_o_rk
adj_d
adj_d_rk
adj_t
adj_t_rk
wab
double. The number of wins above or below the expected total from a bubble team against the same schedule.
nc_elite_sos
nc_fut_sos
nc_cur_sos
ov_elite_sos
ov_fut_sos
ov_cur_sos
seed
year
Defaults to current season (YYYY).
`x_cur_sos` is the current average Barthag rating of opponents.
`x_fut_sos` is the projected average Barthag rating of opponents.
try(bart_ratings(year=2020))
Run the code above in your browser using DataLab