Learn R Programming

toRvik (version 1.1.1)

bart_season_schedule: Get Full Season Schedule

Description

Returns full season schedule for all D-1 teams by year

Usage

bart_season_schedule(
  year = current_season(),
  type = NULL,
  conf = NULL,
  team = NULL
)

Value

Returns a tibble with six columns:

date

double.

type

character. See details.

neutral

logical.

home

character.

away

character.

game_id

character.

Arguments

year

Defaults to current season (YYYY).

type

Filters for game type (see details).

conf

Filters for conference.

team

Filters for team.

Details

Function pulls all games involving at least one D-1 team. Under the `type` column, games are classified by one of four indicators, explained below:

nc

Non-conference games between two D-1 teams.

conf

In-conference games.

post

Post-conference tournament games.

nond1

Games involving one non-D1 team.

Examples

Run this code
try(bart_season_schedule(year=2022))

Run the code above in your browser using DataLab