Learn R Programming

toRvik (version 1.1.1)

bart_team_box: Get Team Box Stats

Description

Returns aggregate team stats back to 2008

Usage

bart_team_box(
  year = NULL,
  start = NULL,
  end = NULL,
  team = NULL,
  conf = NULL,
  split = NULL,
  stat = "total",
  aggregate = FALSE,
  ...
)

Value

Returns a tibble with the number of columns dependent on the year.

Arguments

year

Filters to year.

start

Filters to starting year

end

Filters to ending year

team

Filters to team.

conf

Filters to conf.

split

Split to filter (see details).

stat

Filters for agg. stats (total) or avg. stats (avg)

aggregate

Aggregate all years (TRUE) or return per-year stats when passing a range of years (FALSE; default)

...

Any other parameter accepted by the API endpoint

Details

The `split` argument filters the results by split, explained below:

result

Wins and losses

location

Game location

month

Game month

type

Game type

Examples

Run this code
try(bart_team_box(split='month', team='Duke'))

Run the code above in your browser using DataLab