powered by
Returns aggregate team stats back to 2008
bart_team_box( year = NULL, start = NULL, end = NULL, team = NULL, conf = NULL, split = NULL, stat = "total", aggregate = FALSE, ... )
Returns a tibble with the number of columns dependent on the year.
Filters to year.
Filters to starting year
Filters to ending year
Filters to team.
Filters to conf.
Split to filter (see details).
Filters for agg. stats (total) or avg. stats (avg)
Aggregate all years (TRUE) or return per-year stats when passing a range of years (FALSE; default)
Any other parameter accepted by the API endpoint
The `split` argument filters the results by split, explained below:
Wins and losses
Game location
Game month
Game type
try(bart_team_box(split='month', team='Duke'))
Run the code above in your browser using DataLab