Returns efficiency and four factor finish, conference and overall records,
and basic shooting percentages by year back to 2008.
Usage
bart_team_history(team)
Value
Returns a tibble with 23 columns:
year
double.
t_rk
double.
coach
character.
seed
double.
finish
character.
conf
character.
ov_rec
character.
conf_rec
character.
adj_o
double.
adj_d
double.
efg_o
double.
efg_d
double.
to_percent
double.
tod_percent
double.
or_percent
double.
dr_percent
double.
ftr
double.
ftrd
double.
ft_percent
double.
two_pct
double.
two_pct_d
double.
three_pct
double.
adj_t
double.
Arguments
team
Indicates team to return.
Details
`team` input must be an exact match: 'State' is abbreviated to 'St.' and full
names are used where applicable (e.g. 'North Carolina'). For complete list,
see `team` column of bart_ratings.