Learn R Programming

toRvik (version 1.1.1)

bart_tournament_prediction: T-Rank Tournament Prediction

Description

Returns single-elimination tournament predictions using Barttorvik's model

Usage

bart_tournament_prediction(teams = NULL, date = NULL, sims = NULL, seed = NULL)

Value

Returns a tibble with four columns:

team

character.

wins

integer.

finals

integer.

champ

integer.

Arguments

teams

List of teams arranged in scheduled order

date

Date for tournament

sims

Number of simulations to play

seed

Seed to set for reproducible results

Details

Given a list of teams arranged in scheduled order, function returns tournament predictions for single-elimination tournaments. Teams must be supplied as a character vector and in bracket order. In other words, if team A plays team B and team C plays team D in round one, the function should be supplied `teams=c('A', 'B', 'C', 'D')`.

Examples

Run this code
try(bart_tournament_prediction(teams=c('Duke', 'North Carolina',
'Kansas', 'Villanova'), date='20220402', sims=10, seed=1))

Run the code above in your browser using DataLab