Given a list of teams arranged in scheduled order, function returns
tournament predictions for single-elimination tournaments. Teams must be
supplied as a character vector and in bracket order. In other words, if team
A plays team B and team C plays team D in round one, the function should be
supplied `teams=c('A', 'B', 'C', 'D')`.