Learn R Programming

toRvik (version 1.1.1)

bart_tourney_results: Get NCAA Tournament Results

Description

Returns a tibble with raw and adjusted NCAA tournament results by team, coach, conference, or seed back to 2000.

Usage

bart_tourney_results(
  min_year = 2000,
  max_year = current_season(),
  type = "team"
)

Value

Returns a tibble of adjusted and raw tournament results.

Arguments

min_year

Minimum year to pull -- defaults to 2000 (YYYY).

max_year

Maximum year to pull -- defaults to current season (YYYY).

type

Data split value, defaults to team ('team', 'coach', 'conf', 'seed').

Details

  • PAKE is the number of wins above or below the expected value given a KenPom rating.

Examples

Run this code
try(bart_tourney_results(min_year=2010, max_year=2015, type='conf'))

Run the code above in your browser using DataLab