powered by
Returns a tibble with raw and adjusted NCAA tournament results by team, coach, conference, or seed back to 2000.
bart_tourney_results( min_year = 2000, max_year = current_season(), type = "team" )
Returns a tibble of adjusted and raw tournament results.
Minimum year to pull -- defaults to 2000 (YYYY).
Maximum year to pull -- defaults to current season (YYYY).
Data split value, defaults to team ('team', 'coach', 'conf', 'seed').
PAKE is the number of wins above or below the expected value given a KenPom rating.
try(bart_tourney_results(min_year=2010, max_year=2015, type='conf'))
Run the code above in your browser using DataLab